#
# spec file for package libdiscid
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libdiscid0
Name:           libdiscid
Version:        0.6.4
Release:        1.3
Summary:        Library for gathering DiscIDs and ISRCs from audio CDs
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://musicbrainz.org/doc/libdiscid
Source:         http://ftp.musicbrainz.org/pub/musicbrainz/libdiscid/%{name}-%{version}.tar.gz
Source1000:     baselibs.conf
# PATCH-FEATURE-OPENSUSE libdiscid-no-crypto.patch
Patch0:         libdiscid-no-crypto.patch
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libmusicbrainz5)

%description
libdiscid is a C library for creating MusicBrainz and freedb DiscIDs
from audio CDs.
It reads a CD's table of contents (TOC) and generates an identifier
which can be used to lookup the CD at MusicBrainz.
Additionally, it provides a submission URL for adding the DiscID to the
database and gathers ISRCs and the MCN from disc.

%package -n %{libname}
Summary:        Library for gathering DiscIDs and ISRCs from audio CDs
Group:          Development/Libraries/C and C++

%description -n %{libname}
libdiscid is a C library for creating MusicBrainz and freedb DiscIDs
from audio CDs.
It reads a CD's table of contents (TOC) and generates an identifier
which can be used to lookup the CD at MusicBrainz.
Additionally, it provides a submission URL for adding the DiscID to the
database and gathers ISRCs and the MCN from disc.

%package devel
Summary:        Library for gathering DiscIDs and ISRCs from audio CDs
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libdiscid is a C library for creating MusicBrainz and freedb DiscIDs
from audio CDs.
It reads a CD's table of contents (TOC) and generates an identifier
which can be used to lookup the CD at MusicBrainz.
Additionally, it provides a submission URL for adding the DiscID to the
database and gathers ISRCs and the MCN from disc.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fiv
%configure \
    --disable-silent-rules \
    --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/libdiscid.so.0*

%files devel
%dir %{_includedir}/discid
%{_includedir}/discid/*.h
%{_libdir}/libdiscid.so
%{_libdir}/pkgconfig/libdiscid.pc

%changelog
* Tue Mar 14 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.4:
  * LIB-69: Revert "Use discid_feature enum in discid_read_sparse".
    Fixes compiler errors with C++.
  * LIB-66: fix for Debian kFreeBSD
  * Haiku platform support (TOC only)
  * Use discid_feature enum in discid_read_sparse
  * Fixed building with CMake on macOS
  * LIB-68: provide macOS universal2 binaries with support for both
    x86_64 and arm64
  * LIB-67: Source tarball with updated autotools configuration
  * CMake: Use GNUInstallDirs to determine install location
  * CMake 2.8.12 is now the minimum required version
* Fri Jul  7 2017 tchvatal@suse.com
- Update to 0.6.2:
  * ISRC and MCN support on BSD
  * LIB-60: fix make check for default device on generic/unknown platform
  * make Doxygen output reproducible (no timestamps)
  * remove newline for Linux device "1" from proc
- Refresh patch libdiscid-no-crypto.patch
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
* Mon Jul  4 2016 jengelh@inai.de
- Remove useless --with-pic (it's for unbuilt static libs).
  Remove redundant %%clean.
- Remove nonsense provide, it is not requested by debuginfo.
* Tue Feb 17 2015 idonmez@suse.com
- Add baselibs.conf as source
* Tue Feb 17 2015 p.drouand@gmail.com
- Update to version 0.6.1
  * LIB-59: windows: fix bug preventing ISRC reads
- Changes from version 0.6.0
  * LIB-41: add discid_get_troc_string() for fuzzy toc lookup
  * LIB-54: add libmusicbrainz example with fuzzy toc lookup
  * LIB-43: windows: the default drive is the first cd drive letter
  * LIB-45: Linux/BSD/Solaris: try several possible default device names
  * LIB-28: Mac: allow drive numbers as devices, default now "1"
  * LIB-55, LIB-56: allow drive numbers for Windows and Linux
  * LIB-53: discid_get_submission_url() returns the new NGS url
    currently no functional change, the old url was redirected
  * LIB-52: more validation for parameters of discid_put()
  * LIB-48: assert successful read/put when API is used
  * the discisrc example prints the name of the device used
- Add pkgconfig(libmusicbrainz5) build require; new upstream dependency
- Update libdiscid-no-crypto.patch
* Fri Aug  2 2013 Johannes Dewender <novell@JonnyJD.net>
- update to version 0.5.2:
  - LIB-40: discid_get_webservice_url() (web service version 1) is deprecated
    please use libmusicbrainz to gather metadata by disc ID
  - LIB-7:  rewrote data track handling, releases with multiple data tracks
    This also fixes LIB-18 (no ID for DVDs) and LIB-9 (PS/PS2 CDs)
  - LIB-44: fix invalid disc IDs on first read of multi-session discs
  - LIB-26: add a better test suite, including valgrind memcheck target
  - LIB-37: Autotools optimization (non-recursive build etc.)
  - print time information in the discid example
- libdiscid-no-crypto.patch: refreshed via quilt
* Tue Apr 16 2013 Johannes Dewender <novell@JonnyJD.net>
- update to version 0.5.0:
  - LIB-29: add read_sparse() for faster reading again
  - LIB-35: add HAVE_SPARSE_READ and VERSION_* defines
  - LIB-36: hide internal symbols on Linux/Unix
- libdiscid-visibility.patch removed (implemented upstream)
- libdiscid-no-crypto.patch:
  - refreshed via quilt
  - provided meta information: no upstream, opensuse feature
* Fri Mar  8 2013 Johannes Dewender <novell@JonnyJD.net>
- updated to 0.4.1
  - LIB-23: add has_feature() and get_feature_list() to API (platform check)
  - add get_version_string() to API
  - CMake : add FreeBSD, NetBSD, OpenBSD -> all platforms supported
  - LIB-32: change libtool from -version-info to -version-name
- libdiscid-visibility.patch refreshed via quilt
- libdiscid-no-crypto.patch refreshed via quilt
* Tue Feb 12 2013 Johannes Dewender <novell@JonnyJD.net>
- updated to 0.3.2
  - ISRC and MCN support on Linux
  - Autotools: fix Windows, remove unneeded libs on SunOS
  - CMake: add Cygwin, add SunOS, fix Mac OS X
  - updated docs, created INSTALL file
  - fix distribution so it works for autotools AND cmake
- libdiscid-visibility.patch refreshed for 0.3.2 via quilt
* Mon Jan 14 2013 Johannes Dewender <novell@JonnyJD.net>
- updated to 0.3.0
  - Fixed reading of 99 track CDs on Mac OS X.
  - Added API for reading ISRCs and MCNs (implemented on Windows and Mac OS X).
  - Added Solaris, OpenBSD and kFreeBSD support.
- libdiscid-visibility.patch, libdiscid-no-crypto.patch
  Adapted to the 0.3 release
* Tue Jul 31 2012 crrodriguez@opensuse.org
- autotools fixes, all C files must include config.h
- Use openSSL for crypto, we have waay too many internal
  implementations of common digest algos.
- Run make check
* Sat Jan 28 2012 coolo@suse.com
- fix baselibs.conf
* Sat Nov 19 2011 coolo@suse.com
- update to 0.2.2
  - Set libtool version number to 2:1:2 because it is backwards compatible
    with versions 0.1.x. Thanks to Luks for spotting this.
- ran spec-cleaner and rename shared library package
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Fixed spec file line breaks
- Added BuildRequires:  pkg-config (fix for RPMLINT warning)
* Wed Oct  7 2009 crrodriguez@opensuse.org
- support GCC visilibity features
* Thu Aug 14 2008 crrodriguez@suse.de
- update to version 0.2.1 libdiscid1
  * Addded the discid_get_webservice_url() function
  * other non linux relevant changes
* Wed Dec  5 2007 ro@suse.de
- provide main package name in library package for debuginfo
* Sat Sep  1 2007 crrodriguez@suse.de
- initial version for CODE 11 as a dependency of libmusicbrainz3.
* Sat Aug 18 2007 crrodriguez@suse.de
- firs version for the opensuse buildservice
